@@ -1,5 +1,5 @@
 package Router::Pygmy;
-$Router::Pygmy::VERSION = '0.04';
+$Router::Pygmy::VERSION = '0.05';
 use strict;
 use warnings;
 
@@ -87,7 +87,7 @@ sub path_for {
 sub match {
     my ( $this, $path ) = @_;
 
-    my @parts = grep { $_ } split m{/}, $path;
+    my @parts = grep { length($_) > 0  } split m{/}, $path;
     my @args;
 
     my $lookup = $this->{lookup};
@@ -136,7 +136,7 @@ Router::Pygmy - ultrasimple path router matching paths to names and args
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
